FnR
=====

FnR is a command line utility powered by Python to substitute text in files.

This tool was developed to automate the process of opening a text editor, hitting ctrl+f, typing your search term, switching to replace, typing your replacement term, and repeating for multiple search terms. Instead, with FnR, you input all search and replacement terms at once and BAM!

FnR also supports repeatability by allowing the user to provide the mapping of search/replace terms in a file so if you find yourself repetitively replacing items in similar template files, FnR is perfect for automating your life. :)

## FnR?
The name *fnr* is a twisted acronym for _*Find & Replace*_, or F&R. 
